@@ -950,11 +950,11 @@ def dict_str(data: dict):
     return string
 
 
-def node2dict(node: neo4j.data.Node):
+def node2dict(node: neo4j.graph.Node):
     return {"id": node.id, "labels": list(node.labels), "properties": node._properties}
 
 
-def relationship2dict(relationship: neo4j.data.Relationship):
+def relationship2dict(relationship: neo4j.graph.Relationship):
     return {"start_node": node2dict(relationship.start_node), "end_node": node2dict(relationship.end_node),
             "id": relationship.id,
             "type": relationship.type, "properties": relationship._properties}
@@ -970,23 +970,23 @@ def parse_record(record: neo4j.data.Record, flag=True):
     _record = {"node": [], "relationship": [], "path": [], "other": []}
     if isinstance(record, neo4j.data.Record):
         for rd in record:
-            if isinstance(rd, neo4j.data.Node):
+            if isinstance(rd, neo4j.graph.Node):
                 _record["node"].append(node2dict(rd))
-            elif issubclass(rd.__class__, neo4j.data.Node):
+            elif issubclass(rd.__class__, neo4j.graph.Node):
                 _record["node"].append(node2dict(rd))
-            elif isinstance(rd, neo4j.data.Relationship):
+            elif isinstance(rd, neo4j.graph.Relationship):
                 _record["relationship"].append(relationship2dict(rd))
-            elif issubclass(rd.__class__, neo4j.data.Relationship):
+            elif issubclass(rd.__class__, neo4j.graph.Relationship):
                 _record["relationship"].append(relationship2dict(rd))
             elif isinstance(rd, list) or isinstance(rd, tuple):
                 for x in rd:
-                    if isinstance(x, neo4j.data.Node):
+                    if isinstance(x, neo4j.graph.Node):
                         _record["node"].append(node2dict(x))
-                    elif issubclass(x.__class__, neo4j.data.Node):
+                    elif issubclass(x.__class__, neo4j.graph.Node):
                         _record["node"].append(node2dict(x))
-                    elif isinstance(x, neo4j.data.Relationship):
+                    elif isinstance(x, neo4j.graph.Relationship):
                         _record["relationship"].append(relationship2dict(x))
-                    elif issubclass(x.__class__, neo4j.data.Relationship):
+                    elif issubclass(x.__class__, neo4j.graph.Relationship):
                         _record["relationship"].append(relationship2dict(x))
                     elif isinstance(rd, neo4j.graph.Path):
                         _record["path"].append(path2dict(rd))
