@@ -111,20 +111,18 @@ def get_args(func):
             parameter_default = None
             if parameter.default is not inspect.Parameter.empty:
                 parameter_default = parameter.default
-            parameter_type_str = "string"
-            if not isinstance(parameter_type, type):
-                if isinstance(parameter_type, int):
-                    parameter_type_str = "integer"
-                elif isinstance(parameter_type, str):
-                    parameter_type_str = "string"
-                elif isinstance(parameter_type, list) or isinstance(parameter_type, tuple):
-                    parameter_type_str = "array"
-                elif isinstance(parameter_type, dict):
-                    parameter_type_str = "object"
-                elif issubclass(parameter_type, object):
-                    parameter_type_str = "object"
-                elif issubclass(parameter_type, bool):
-                    parameter_type_str = "boolean"
+            if parameter_type == int:
+                parameter_type_str = "integer"
+            elif parameter_type == str:
+                parameter_type_str = "string"
+            elif parameter_type in [list, tuple, set]:
+                parameter_type_str = "array"
+            elif parameter_type == float:
+                parameter_type_str = "number"
+            elif parameter_type == bool:
+                parameter_type_str = "boolean"
+            else:
+                parameter_type_str = "object"
             params = {
                 "required": False if parameter.default is not inspect.Parameter.empty else True,
                 "name": parameter_name,
